@@ -1,35 +1,17 @@
 /* -*- C++ -*-
+    This file implements the Collection class.
 
-This file implements the Collection class.
+    SPDX-FileCopyrightText: 2004-2013 Mirko Boehm <mirko@kde.org>
 
-$ Author: Mirko Boehm $
-$ Copyright: (C) 2004-2013 Mirko Boehm $
-$ Contact: mirko@kde.org
-https://www.kde.org
-http://creative-destruction.me $
-
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "collection.h"
 
-#include "queueapi.h"
-#include "debuggingaids.h"
-#include "queueing.h"
 #include "collection_p.h"
+#include "debuggingaids.h"
+#include "queueapi.h"
+#include "queueing.h"
 
 #include <QList>
 #include <QObject>
@@ -41,20 +23,21 @@ http://creative-destruction.me $
 
 namespace ThreadWeaver
 {
-
 class CollectionExecuteWrapper : public ExecuteWrapper
 {
 public:
     CollectionExecuteWrapper()
         : collection(nullptr)
-    {}
+    {
+    }
 
     void setCollection(Collection *collection_)
     {
         collection = collection_;
     }
 
-    void begin(const JobPointer& job, Thread *thread) override {
+    void begin(const JobPointer &job, Thread *thread) override
+    {
         TWDEBUG(4, "CollectionExecuteWrapper::begin: collection %p\n", collection);
         ExecuteWrapper::begin(job, thread);
         Q_ASSERT(collection);
@@ -62,16 +45,18 @@ public:
         ExecuteWrapper::begin(job, thread);
     }
 
-    void end(const JobPointer& job, Thread *thread) override {
+    void end(const JobPointer &job, Thread *thread) override
+    {
         TWDEBUG(4, "CollectionExecuteWrapper::end: collection %p\n", collection);
         Q_ASSERT(collection);
         ExecuteWrapper::end(job, thread);
         collection->d()->elementFinished(collection, job, thread);
     }
 
-    void cleanup(const JobPointer& job, Thread *) override {
-        //Once job is unwrapped from us, this object is dangling. Job::executor points to the next higher up execute wrapper.
-        //It is thus safe to "delete this". By no means add any later steps after delete!
+    void cleanup(const JobPointer &job, Thread *) override
+    {
+        // Once job is unwrapped from us, this object is dangling. Job::executor points to the next higher up execute wrapper.
+        // It is thus safe to "delete this". By no means add any later steps after delete!
         delete unwrap(job);
     }
 
@@ -93,7 +78,8 @@ Collection::~Collection()
 {
     MUTEX_ASSERT_UNLOCKED(mutex());
     // dequeue all remaining jobs:
-    QMutexLocker l(mutex()); Q_UNUSED(l);
+    QMutexLocker l(mutex());
+    Q_UNUSED(l);
     if (d()->api != nullptr) { // still queued
         d()->dequeueElements(this, false);
     }
@@ -101,7 +87,8 @@ Collection::~Collection()
 
 void Collection::addJob(JobPointer job)
 {
-    QMutexLocker l(mutex()); Q_UNUSED(l);
+    QMutexLocker l(mutex());
+    Q_UNUSED(l);
     REQUIRE(d()->api == nullptr || d()->selfIsExecuting == true); // not queued yet or still running
     REQUIRE(job != nullptr);
 
@@ -114,7 +101,8 @@ void Collection::addJob(JobPointer job)
 void Collection::stop(JobPointer job)
 {
     Q_UNUSED(job);
-    QMutexLocker l(mutex()); Q_UNUSED(l);
+    QMutexLocker l(mutex());
+    Q_UNUSED(l);
     d()->stop_locked(this);
 }
 
@@ -139,10 +127,11 @@ void Collection::aboutToBeDequeued_locked(QueueAPI *api)
     Job::aboutToBeDequeued_locked(api);
 }
 
-void Collection::execute(const JobPointer& job, Thread *thread)
+void Collection::execute(const JobPointer &job, Thread *thread)
 {
     {
-        QMutexLocker l(mutex()); Q_UNUSED(l);
+        QMutexLocker l(mutex());
+        Q_UNUSED(l);
         Q_ASSERT(d()->self.isNull());
         Q_ASSERT(d()->api != nullptr);
         d()->self = job;
@@ -153,17 +142,17 @@ void Collection::execute(const JobPointer& job, Thread *thread)
 
 void Collection::run(JobPointer, Thread *)
 {
-    //empty
+    // empty
 }
 
 Private::Collection_Private *Collection::d()
 {
-    return reinterpret_cast<Private::Collection_Private*>(Job::d());
+    return reinterpret_cast<Private::Collection_Private *>(Job::d());
 }
 
 const Private::Collection_Private *Collection::d() const
 {
-    return reinterpret_cast<const Private::Collection_Private*>(Job::d());
+    return reinterpret_cast<const Private::Collection_Private *>(Job::d());
 }
 
 JobPointer Collection::jobAt(int i)
@@ -175,15 +164,16 @@ JobPointer Collection::jobAt(int i)
 
 int Collection::elementCount() const
 {
-    QMutexLocker l(mutex()); Q_UNUSED(l);
+    QMutexLocker l(mutex());
+    Q_UNUSED(l);
     return jobListLength_locked();
 }
 
-
 #if THREADWEAVER_BUILD_DEPRECATED_SINCE(5, 0)
 int Collection::jobListLength() const
 {
-    QMutexLocker l(mutex()); Q_UNUSED(l);
+    QMutexLocker l(mutex());
+    Q_UNUSED(l);
     return jobListLength_locked();
 }
 #endif
@@ -212,4 +202,3 @@ Collection &Collection::operator<<(JobInterface &job)
 }
 
 }
-
